@@ -9,7 +9,7 @@ class GraphManager:
 
     def CreateTrainAndSaveGCN(self):
         traindata, testdata = load_train_test_split(self.save_dataset_path)
-        CreateTrainAndSaveGCN(traindata, testdata)
+        CreateTrainAndSaveGCN(traindata, testdata, self.save_dataset_path)
         print("===== Modèle entrainé et sauvegardé =====")
 
     def single_prediction(self, saved_model_folder, prediction_dataset_folder, document_to_predict, labels_tab):
