@@ -2,7 +2,7 @@ import os
 import torch
 from sklearn.metrics import confusion_matrix, classification_report
 from sklearn.utils.class_weight import compute_class_weight
-from GCN import GCN
+from graphmanagerlib.GCN import GCN
 import torch.nn.functional as F
 
 
